pub(super) struct SymmetricKey(pub(crate) [u8; 32]);Expand description
A newtype for symmetric keys used in noise. A noise key is always 256-bits.
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl Clone for SymmetricKey
impl Clone for SymmetricKey
Sourcefn clone(&self) -> SymmetricKey
fn clone(&self) -> SymmetricKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SymmetricKey
Implement Debug manually to avoid accidentally logging the key material.
impl Debug for SymmetricKey
Implement Debug manually to avoid accidentally logging the key material.
Sourceimpl<'de> Deserialize<'de> for SymmetricKey
impl<'de> Deserialize<'de> for SymmetricKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Drop for SymmetricKey
impl Drop for SymmetricKey