pub(crate) struct PersistentTransportState {
transport_cipher: TransportCipher,
send_key: SymmetricKey,
receive_key: SymmetricKey,
send_nonce: u64,
receive_nonce: u64,
last_handshake_time: u64,
}Fields
transport_cipher: TransportCiphersend_key: SymmetricKeyreceive_key: SymmetricKeysend_nonce: u64receive_nonce: u64last_handshake_time: u64Implementations
Sourceimpl PersistentTransportState
impl PersistentTransportState
Sourcepub(crate) fn new(
send_key: SymmetricKey,
receive_key: SymmetricKey,
transport_cipher: TransportCipher,
) -> Self
pub(crate) fn new( send_key: SymmetricKey, receive_key: SymmetricKey, transport_cipher: TransportCipher, ) -> Self
Create a new transport state with the given keys and cipher.
pub(crate) fn should_rehandshake(&self, rehandshake_interval_secs: u64) -> bool
pub(crate) fn is_older_than( &self, now_epoch_secs: u64, max_age_secs: u64, ) -> bool
Sourceimpl PersistentTransportState
impl PersistentTransportState
Sourcepub(crate) fn send(&mut self, payload: Payload) -> Result<TransportFrame, ()>
pub(crate) fn send(&mut self, payload: Payload) -> Result<TransportFrame, ()>
Encrypts the message, mutates the state and returns the transport frame to be sent over IPC.
Sourcepub(crate) fn receive(
&mut self,
transport_frame: &TransportFrame,
) -> Result<Payload, ReceiveError>
pub(crate) fn receive( &mut self, transport_frame: &TransportFrame, ) -> Result<Payload, ReceiveError>
Decrypts the transport frame, mutates the state and returns the plaintext message.
fn encrypt(&self, key: &SymmetricKey, nonce: u64, payload: &Payload) -> Vec<u8> ⓘ
fn try_decrypt( &self, key: &SymmetricKey, transport_message: &TransportFrame, ) -> Result<Vec<u8>, ()>